Our vision is that the AEA framework enables businesses of all sizes, from single independent developers to large corporations and consortiums, to create and deploy agent-based solutions in different domains, thus contributing to and advancing a decentralized agent economy as envisaged by Fetch.ai.

## Open source technology for everyone

We are creating infrastructure for developers to build their own agent-based solutions. 

AEA users include, amongst others:

* Data scientists
* Economists
* Researchers (Artificial Intelligence, Machine Learning, Multi-Agent Systems)
* Engineers
* Machine learning experts
* Independent developers
* Students and academics
* Crypto connoisseurs and enthusiasts
* Web developers

<br />